@@ -4,13 +4,17 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 # setup our tests and etc
 use Test::Strict;
 
 # does our stuff!
 sub do_test {
+	# Set some useful stuff
+	local $Test::Strict::TEST_WARNINGS = 1;
+#	local $Test::Strict::TEST_SKIP = [ 'Build.PL', 'Makefile.PL', 'Build' ]; # TODO ineffective... need to pester T::S author to fix!
+
 	all_perl_files_ok();
 
 	return;
@@ -34,6 +38,8 @@ Encapsulates Test::Strict functionality.
 
 Encapsulates Test::Strict functionality.
 
+We make sure that Test::Strict tests strict/warnings and exempts the Build.PL/Makefile.PL files from checks.
+
 =head1 EXPORT
 
 None.
